@@ -33,10 +33,10 @@
 #include <qprogressbar.h>
 #include <kiconloader.h>
 
-#include <qvariant.h>
-#include <qpainter.h>
+#include <QVariant>
+#include <QPainter>
 #include <q3header.h>
-#include <qcursor.h>
+#include <QCursor>
 #include <Q3PtrList>
 #include <QPixmap>
 #include <QFocusEvent>
@@ -286,7 +286,7 @@ InfoList::hideColumn( int c )
     if ( sortcol == p && header()->count() > 0 ) //neededtopreventcrashes
         setSorting( (p > 0) ? p - 1 : 0 );
 
-    m_visibleReal.remove( m_visibleReal.at( p ) );
+    m_visibleReal.removeAt( m_visibleReal.at( p ) );
     m_realVisible.remove( c );
 
     if ( m_headerMenu )
@@ -565,9 +565,9 @@ DownloadFile::xtext( int column ) const
                 case FileInfo::Shared: return i18nc( "file is being shared", "Shared" );
                 case FileInfo::Cancelled: return i18nc( "file has been canceled", "Canceled" );
                 case FileInfo::New: return i18nc( "new file added to list", "New" );
-                case FileInfo::Aborted: return i18nc( "file has been aborted with a reason", "Aborted: %1" ).arg( it->fileAbortedMsg() );
+                case FileInfo::Aborted: return i18nc( "file has been aborted with a reason", "Aborted: %1", it->fileAbortedMsg() );
                 case FileInfo::Queued: return i18nc( "file has been queued", "Queued" );
-                default: return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)" ).arg( it->fileState() );
+                default: return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)", it->fileState() );
             }
 
             return i18nc( "unknown file state", "Unknown" );
@@ -585,7 +585,7 @@ DownloadFile::xtext( int column ) const
             return FileInfo::humanReadableTime( age, true );
         }
         case 13: // filetype
-            return KMimeType::findByUrl( KUrl( "file:/" + it->fileName() ), 0, false, true )->comment();
+            return KMimeType::findByUrl( KUrl::fromPath( it->fileName() ), 0, false, true )->comment();
 
         default:
             return "ERROR!";
@@ -808,7 +808,7 @@ QString DownloadedFile::xtext( int column ) const
         case 4: // hash
             return it->fileUid();
         case 5: // filetype
-            return KMimeType::findByUrl( KUrl( "file:/" + it->fileName() ), 0, false, true )->comment();
+            return KMimeType::findByUrl( KUrl::fromPath( it->fileName() ), 0, false, true )->comment();
 
         default:
             return "ERROR!";
@@ -916,7 +916,7 @@ QString ServerInfoItem::xtext( int column ) const
                     return i18nc( "host is blacklisted", "Blacklisted" );
 
                 default:
-                    return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)" ).arg( it->serverState() );
+                    return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)", it->serverState() );
             }
         case 3: // users
             return KGlobal::locale()->formatNumber( it->serverNUsers(), 0 );
@@ -1110,7 +1110,7 @@ QString ClientItem::xtext( int column ) const
                     return i18nc( "host is blacklisted", "Blacklisted" );
 
                 default:
-                    return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)" ).arg( it->clientState() );
+                    return i18nc( "unknown host state (unknown ID code)", "Unknown (%1)", it->clientState() );
             }
 
         default:
