@@ -23,7 +23,7 @@
 #ifndef __kmldonkey_systemtray_h__
 #define __kmldonkey_systemtray_h__
 
-#include <qtooltip.h>
+#include <QToolTip>
 #include <qwidget.h>
 #include <ksystemtrayicon.h>
 
