@@ -23,7 +23,7 @@
 #ifndef __kmldonkey_clipboard_h__
 #define __kmldonkey_clipboard_h__
 
-#include <qstringlist.h>
+#include <QStringList>
 
 class ClipboardHelper
 {
